@@ -26,7 +26,9 @@
 #include <netinet/in.h>
 #include "net-support.h"
 #include "pathnames.h"
-#include "intl.h"
+#define  EXTERN
+#include "net-locale.h"
+
 
 /* Display a ddp domain address. */
 static char *
@@ -46,7 +48,7 @@ ddp_sprint(struct sockaddr *sap, int numeric)
   static char buf[64];
 
   if (sap->sa_family != AF_APPLETALK)
-	return strncpy (buf, _("[NONE SET]"), sizeof (buf));
+    return(NLS_CATBUFF (catfd, ddpSet, ddp_none, "[NONE SET]", buf, 64));
   return(ddp_print(sap->sa_data));
 }
 
