@@ -17,6 +17,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <netinet/ip6.h>
 #ifndef __GLIBC__
 #include <netinet6/ipv6_route.h>  /* glibc doesn't have this */
 #endif
@@ -96,7 +97,6 @@ int rprint_fib6(int ext, int numeric)
 #if 0
 	if (num < 23) continue;
 #endif
-	if (!(iflags & RTF_UP)) continue;
 	/* Fetch and resolve the target address. */
 	sprintf(addr6, "%s:%s:%s:%s:%s:%s:%s:%s",
 		addr6p[0], addr6p[1], addr6p[2], addr6p[3],
@@ -115,7 +115,8 @@ int rprint_fib6(int ext, int numeric)
 		inet6_aftype.sprint((struct sockaddr *)&snaddr6, 1));
 	
 	/* Decode the flags. */
-	strcpy(flags, "U");
+	flags[0] = '\0';
+	if (iflags & RTF_UP) strcat(flags, "U");
 	if (iflags & RTF_GATEWAY) strcat(flags, "G");
 	if (iflags & RTF_HOST) strcat(flags, "H");
 	if (iflags & RTF_DEFAULT) strcat(flags, "D");
