@@ -1,8 +1,3 @@
-/*
-  Modifications:
-  1998-07-01 - Arnaldo Carvalho de Melo - GNU gettext instead of catgets
-*/
-
 #include "config.h"
 
 #if HAVE_AFINET
@@ -23,70 +18,54 @@
 #include "version.h"
 #include "net-support.h"
 #include "pathnames.h"
-#include "intl.h"
+#define  EXTERN
+#include "net-locale.h"
+
 #include "net-features.h"
-#include "proc.h"
 
 extern     struct aftype   inet_aftype;
 
 
 int rprint_fib(int ext, int numeric)
 {
-  char buff[1024], iface[16], flags[16];
+  char buff[4096], iface[16], flags[16];
   char gate_addr[128], net_addr[128];
   char mask_addr[128];
   struct sockaddr snet, sgate, smask;
   int num, iflags, metric, refcnt, use, mss, window, irtt;
   FILE *fp=fopen(_PATH_PROCNET_ROUTE, "r");
-  char *fmt;	
 
   if (!fp) {
 	ESYSNOT("getroute","INET FIB");
 	return 1;
   }
 
-  printf(_("Kernel IP routing table\n"));
+  printf(NLS_CATGETS(catfd, inetSet, inet_table, "Kernel IP routing table\n"));
 
   if (ext == 1)
-	printf(_("Destination     Gateway         Genmask         "
-		 "Flags Metric Ref    Use Iface\n"));
+	printf(NLS_CATGETS(catfd, inetSet, inet_header1,
+		"Destination     Gateway         Genmask         "
+		"Flags Metric Ref    Use Iface\n"));
   if (ext == 2)
-	printf(_("Destination     Gateway         Genmask         "
-		 "Flags   MSS Window  irtt Iface\n"));
+	printf(NLS_CATGETS(catfd, inetSet, inet_header2,
+		"Destination     Gateway         Genmask         "
+		"Flags   MSS Window  irtt Iface\n"));
   if (ext >= 3)
-	printf(_("Destination     Gateway         Genmask         "
-		 "Flags Metric Ref    Use Iface    "
-		 "MSS   Window irtt\n"));
+	printf(NLS_CATGETS(catfd, inetSet, inet_header3,
+		"Destination     Gateway         Genmask         "
+		"Flags Metric Ref    Use Iface    "
+		"MSS   Window irtt\n"));
 
   irtt=0;
   window=0;
   mss=0;
-
-  fmt = proc_gen_fmt(_PATH_PROCNET_ROUTE, fp,
-					 "Iface", "%16s",
-					 "Destination", "%128s",
-					 "Gateway", "%128s",
-					 "Flags", "%X",
-					 "RefCnt", "%d", 
-					 "Use",  "%d", 
-					 "Metric", "%d", 
-					 "Mask", "%128s",
-					 "MTU", "%d", 
-					 "Window", "%d",
-					 "IRTT", "%d", 
-					 NULL); 
-  /* "%16s %128s %128s %X %d %d %d %128s %d %d %d\n" */ 
-
-  if (!fmt) 
-	  return 1; 
-
   while (fgets(buff, 1023, fp))
   {
-	num = sscanf(buff, fmt, 
+	num = sscanf(buff, "%s %s %s %X %d %d %d %s %d %d %d\n",
 		iface, net_addr, gate_addr,
 		&iflags, &refcnt, &use, &metric, mask_addr,
  		&mss,&window,&irtt);
-	if (num < 10 || !(iflags & RTF_UP)) continue;
+	if (num < 10) continue;
 
 	/* Fetch and resolve the target address. */
 	(void)inet_aftype.input(1, net_addr, &snet);
@@ -104,7 +83,8 @@ int rprint_fib(int ext, int numeric)
 	mask_addr[15] = '\0';
 
 	/* Decode the flags. */
-	strcpy(flags, "U");
+	flags[0] = '\0';
+	if (iflags & RTF_UP) strcat(flags, "U");
 	if (iflags & RTF_GATEWAY) strcat(flags, "G");
 #if HAVE_RTF_REJECT
 	if (iflags & RTF_REJECT) strcpy(flags,"!");
@@ -149,19 +129,17 @@ int rprint_fib(int ext, int numeric)
 	}
   }
 
-  free(fmt); 
   (void) fclose(fp);
   return(0);
 }
 
 int rprint_cache(int ext, int numeric)
 {
-  char buff[1024], iface[16], flags[16];
+  char buff[4096], iface[16], flags[16];
   char gate_addr[128], net_addr[128];
   char mask_addr[128];
   struct sockaddr snet, sgate, smask;
   int num, iflags, metric, refcnt, use, mss, window, irtt, hh, arp;
-  char *fmt; 
 
   FILE *fp=fopen(_PATH_PROCNET_RTCACHE, "r");
 
@@ -171,30 +149,18 @@ int rprint_cache(int ext, int numeric)
   }
 
   if (ext == 1)
-	printf(_("Destination     Gateway         Source          "
-		 "Flags Metric Ref    Use Iface\n"));
+	printf(NLS_CATGETS(catfd, inetSet, inet_header1,
+		"Destination     Gateway         Source          "
+		"Flags Metric Ref    Use Iface\n"));
   if (ext == 2)
-	printf(_("Destination     Gateway         Source          "
-		 "Flags   MSS Window  irtt Iface\n"));
+	printf(NLS_CATGETS(catfd, inetSet, inet_header2,
+		"Destination     Gateway         Source          "
+		"Flags   MSS Window  irtt Iface\n"));
   if (ext >= 3)
-	printf(_("Destination     Gateway         Source          "
-		 "Flags Metric Ref    Use Iface    "
-		 "MSS   Window irtt   HH  Arp\n"));
-
-  fmt = proc_gen_fmt(_PATH_PROCNET_ROUTE, fp,
-					 "Iface", "%16s",
-					 "Destination", "%128s",
-					 "Gateway", "%128s",
-					 "Flags", "%X",
-					 "RefCnt", "%d", 
-					 "Use",  "%d", 
-					 "Metric", "%d", 
-					 "Mask", "%128s",
-					 "MTU", "%d", 
-					 "Window", "%d",
-					 "IRTT", "%d", 
-					 NULL); 
-  /* "%16s %128s %128s %X %d %d %d %128s %d %d %d %d %d\n" */ 
+	printf(NLS_CATGETS(catfd, inetSet, inet_header3,
+		"Destination     Gateway         Source          "
+		"Flags Metric Ref    Use Iface    "
+		"MSS   Window irtt   HH  Arp\n"));
 
   irtt=0;
   window=0;
@@ -203,7 +169,7 @@ int rprint_cache(int ext, int numeric)
   arp=0;
   while (fgets(buff, 1023, fp))
   {
-	num = sscanf(buff, fmt,
+	num = sscanf(buff, "%s %s %s %X %d %d %d %s %d %d %d %d %d\n",
 		iface, net_addr, gate_addr,
 		&iflags, &refcnt, &use, &metric, mask_addr,
 		&mss,&window,&irtt,&hh,&arp);
@@ -271,7 +237,6 @@ int rprint_cache(int ext, int numeric)
 	}
   }
 
-  free(fmt); 
   (void) fclose(fp);
   return(0);
 }
