@@ -9,9 +9,6 @@
  *		Public  License as  published  by  the  Free  Software
  *		Foundation;  either  version 2 of the License, or  (at
  *		your option) any later version.
- * Modifications:
- * 1998-07-01 - Arnaldo Carvalho de Melo - GNU gettext instead of catgets,
- *                                         snprintf instead of sprintf
  */
 #include "config.h"
 
@@ -19,11 +16,7 @@
 #include <asm/types.h>
 #include <sys/types.h>
 #include <sys/socket.h>
-#if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 1)
-#include <netipx/ipx.h>
-#else
 #include "ipx.h"
-#endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
@@ -34,7 +27,8 @@
 #include "version.h"
 #include "net-support.h"
 #include "pathnames.h"
-#include "intl.h"
+#define  EXTERN
+#include "net-locale.h"
 
 #if (IPX_NODE_LEN != 6)
 #error "IPX_NODE_LEN != 6"
@@ -54,15 +48,15 @@ IPX_print(unsigned char *ptr)
       break;
 
   if (t && ntohl(sipx->sipx_network))   
-    snprintf(buff,sizeof(buff),"%08lX:%02X%02X%02X%02X%02X%02X",
+    sprintf(buff,"%08lX:%02X%02X%02X%02X%02X%02X",
   	(long int)ntohl(sipx->sipx_network),
   	(int)sipx->sipx_node[0],(int)sipx->sipx_node[1],
   	(int)sipx->sipx_node[2],(int)sipx->sipx_node[3],
   	(int)sipx->sipx_node[4],(int)sipx->sipx_node[5]);
   else if (!t && ntohl(sipx->sipx_network))
-    snprintf(buff,sizeof(buff),"%08lX", (long int)ntohl(sipx->sipx_network));
+    sprintf(buff,"%08lX", (long int)ntohl(sipx->sipx_network));
   else if (t && !ntohl(sipx->sipx_network))
-    snprintf(buff,sizeof(buff),"%02X%02X%02X%02X%02X%02X",
+    sprintf(buff,"%02X%02X%02X%02X%02X%02X",
   	(int)sipx->sipx_node[0],(int)sipx->sipx_node[1],
   	(int)sipx->sipx_node[2],(int)sipx->sipx_node[3],
   	(int)sipx->sipx_node[4],(int)sipx->sipx_node[5]);
@@ -79,7 +73,7 @@ IPX_sprint(struct sockaddr *sap, int numeric)
   static char buf[64];
 
   if (sap->sa_family != AF_IPX)
-	return strncpy (buf, _("[NONE SET]"), sizeof (buf));
+    return(NLS_CATBUFF (catfd, ipxSet, ipx_none, "[NONE SET]", buf, 64));
   return(IPX_print(sap->sa_data));
 }
 
