@@ -19,7 +19,8 @@
 #include "version.h"
 #include "net-support.h"
 #include "pathnames.h"
-#include "intl.h"
+#define  EXTERN
+#include "net-locale.h"
 
 #include "net-features.h"
 
@@ -39,7 +40,7 @@ static int usage(void)
 int IPX_rinput(int action, int ext, char **args)
 {
   
-  fprintf(stderr,_("IPX: this needs to be written\n"));
+  fprintf(stderr,"IPX: this needs to be written\n");
   return(0);
 }
 #endif	/* HAVE_AFIPX */
