@@ -1,21 +1,30 @@
 /*
  * lib/pathnames.h	This file contains the definitions of the path 
- *			names used by the NET-LIB.
+ *			names used by the NET-LIB. Do not change the values!
  *
  * NET-LIB	
  *
- * Version:	lib/pathnames.h 1.37 (1997-08-23)
+ * Version:	lib/pathnames.h 1.36 (1996-04-13)
+ *
+ * Maintainer:	Bernd 'eckes' Eckenfels, <net-tools@lina.inka.de>
  *
  * Author:	Fred N. van Kempen, <waltje@uwalt.nl.mugnet.org>
+ *
+ * Modification:
+ *960125 {1.31}	Bernd Eckenfels: 	Major cleanup, junk removed.
+ *960131 {1.32}	Bernd Eckenfels:	/proc/net/ip_*
+ *960204 {1.33} Bernd Eckenfels:	/dev/net/route
+ *960215 {1.34} Bernd Eckenfels:	/proc/net/ax25_route,nr_*
+ *960322 {1.35} Bernd Eckenfels:	moved to the lib directory
+ *960413 {1.36} Bernd Eckenfels:	/proc/net/rt_cache
+ *
  */
 
-/* pathnames of the procfs files used by NET. */
+/* Pathnames of the PROCfs files used by NET. */
+
 # define _PATH_PROCNET_TCP		"/proc/net/tcp"
-# define _PATH_PROCNET_TCP6		"/proc/net/tcp6"
 # define _PATH_PROCNET_UDP		"/proc/net/udp"
-# define _PATH_PROCNET_UDP6		"/proc/net/udp6"
 # define _PATH_PROCNET_RAW		"/proc/net/raw"
-# define _PATH_PROCNET_RAW6		"/proc/net/raw6"
 # define _PATH_PROCNET_UNIX		"/proc/net/unix"
 # define _PATH_PROCNET_ROUTE		"/proc/net/route"
 # define _PATH_PROCNET_ROUTE6		"/proc/net/ipv6_route"
@@ -34,13 +43,12 @@
 # define _PATH_PROCNET_IP_ACC		"/proc/net/ip_acct"
 # define _PATH_PROCNET_IP_MASQ		"/proc/net/ip_masquerade"
 # define _PATH_PROCNET_NDISC		"/proc/net/ndisc"
-# define _PATH_PROCNET_IFINET6		"/proc/net/if_inet6"
-# define _PATH_PROCNET_DEV		"/proc/net/dev"
-# define _PATH_PROCNET_RARP		"/proc/net/rarp"
-# define _PATH_ETHERS			"/etc/ethers"
-# define _PATH_PROCNET_ROSE_ROUTE	"/proc/net/rose_routes"
 
-/* pathname for the netlink device */
+
+/* Pathnames for the Netlink Devices */
+
 # define _PATH_DEV_ROUTE	"/dev/route"
 
+
+
 /* End of pathnames.h */
