@@ -18,6 +18,9 @@
 #include <unistd.h>
 #include "net-support.h"
 #include "pathnames.h"
+#define  EXTERN
+#include "net-locale.h"
+
 
 extern struct hwtype ether_hwtype;
 
