@@ -6,10 +6,8 @@
  * Usage:       rarp -d hostname                      Delete entry
  *		rarp -s hostname ethernet_address     Add entry
  *              rarp -a                               Print entries
- *		rarp -f				      Add frop /etc/ethers
  *
  * Rewritten: Phil Blundell <Philip.Blundell@pobox.com>  1997-08-03
- * gettext instead of catgets: Arnaldo Carvalho de Melo <acme@conectiva.com.br> 1998-06-29
  *
  */
 
@@ -30,19 +28,19 @@
 #include <getopt.h>
 
 #include "config.h"
-#include "intl.h"
+#include "net-locale.h"
 #include "net-support.h"
 #include "version.h"
-#include "pathnames.h"
 
-static char no_rarp_message[] = N_("This kernel does not support RARP.\n");
+#define PROC_NET_RARP		"/proc/net/rarp"
+#define NO_RARP_MESSAGE         "This kernel does not support RARP.\n"
 
-static char version_string[] = RELEASE "\nrarp 1.02 (1998-06-30)\n";
+static char version_string[] = RELEASE "\nrarp 1.00 (1997-08-03)\n";
 
 static struct hwtype *hardware = NULL;
 
-/* Delete an entry from the RARP cache. */
-static int rarp_delete(int fd, struct hostent *hp)
+/* Delete an entry from the ARP cache. */
+static int arp_delete(int fd, struct hostent *hp)
 {
   struct arpreq req;
   struct sockaddr_in *si;
@@ -64,7 +62,7 @@ static int rarp_delete(int fd, struct hostent *hp)
       case ENXIO:
 	break;
       case ENODEV:
-	fputs(_(no_rarp_message), stderr);
+	fputs(NO_RARP_MESSAGE, stderr);
 	return 1;
       default:
 	perror("SIOCDRARP");
@@ -74,20 +72,21 @@ static int rarp_delete(int fd, struct hostent *hp)
   }
 
   if (found == 0) 
-    printf(_("no RARP entry for %s.\n"), hp->h_name);
+    printf(NLS_CATGETS(catfd, rarpSet, rarp_noentry, 
+		       "no RARP entry for %s.\n"), hp->h_name);
   return 0;
 }
 
 
-/* Set an entry in the RARP cache. */
-static int rarp_set(int fd, struct hostent *hp, char *hw_addr)
+/* Set an entry in the ARP cache. */
+static int arp_set(int fd, struct hostent *hp, char *hw_addr)
 {
   struct arpreq req;
   struct sockaddr_in *si;
   struct sockaddr sap;
 
   if (hardware->input(hw_addr, &sap)) {
-    fprintf(stderr, _("%s: bad hardware address\n"), hw_addr);
+    fprintf(stderr, "%s: bad hardware address\n", hw_addr);
     return 1;
   }
 
@@ -102,7 +101,7 @@ static int rarp_set(int fd, struct hostent *hp, char *hw_addr)
   /* Call the kernel. */
   if (ioctl(fd, SIOCSRARP, &req) < 0) {
     if (errno == ENODEV)
-      fputs(_(no_rarp_message), stderr);
+      fputs(NO_RARP_MESSAGE, stderr);
     else
       perror("SIOCSRARP");
     return  1;
@@ -110,54 +109,15 @@ static int rarp_set(int fd, struct hostent *hp, char *hw_addr)
   return 0;
 }
 
-/* Process an EtherFile */
-static int rarp_file(int fd, const char *name)
-{
-  char buff[1024];
-  char *host, *addr;
-  int linenr;
-  FILE *fp;
-  struct hostent *hp;
-
-  if ((fp = fopen(name, "r")) == NULL) {
-    fprintf(stderr, _("rarp: cannot open file %s:%s.\n"), name, strerror(errno));
-    return -1;
-  }
-
-  /* Read the lines in the file. */
-  linenr = 0;
-  while (fgets(buff, sizeof(buff), fp)) {
-    ++linenr;
-    if (buff[0] == '#' || buff[0] == '\0') 
-      continue;
-    if ((addr = strtok(buff, "\n \t")) == NULL) 
-      continue;
-    if ((host = strtok(NULL, "\n \t")) == NULL) {
-      fprintf(stderr, _("rarp: format error at %s:%u\n"), name, linenr);
-      continue;
-    }
-    
-    if ((hp = gethostbyname(host)) == NULL) {
-      fprintf(stderr, _("rarp: %s: unknown host\n"), host);
-    }
-    if (rarp_set(fd,hp,addr) != 0) {
-      fprintf(stderr, _("rarp: cannot set entry from %s:%u\n"), name, linenr);
-    }
-  }
-  
-  (void) fclose(fp);
-  return 0;
-}
- 
 static int display_cache(void)
 {
-  FILE *fd = fopen(_PATH_PROCNET_RARP, "r");
+  FILE *fd = fopen(PROC_NET_RARP, "r");
   char buffer[256];
   if (fd == NULL) {
     if (errno == ENOENT) 
-      fputs(_(no_rarp_message), stderr);
+      fputs(NO_RARP_MESSAGE, stderr);
     else
-      perror(_PATH_PROCNET_RARP);
+      perror(PROC_NET_RARP);
     return 1;
   }
   while (feof(fd) == 0) {
@@ -170,18 +130,21 @@ static int display_cache(void)
 
 static void usage(void)
 {
-  fprintf(stderr, _("Usage: rarp -a                               list entries in cache.\n"));
-  fprintf(stderr, _("       rarp -d hostname                      delete entry from cache.\n"));
-  fprintf(stderr, _("       rarp [-t hwtype] -s hostname hwaddr   add entry to cache.\n"));
-  fprintf(stderr, _("       rarp -f                               add entries from ethers.\n"));
-  fprintf(stderr, _("       rarp -V                               display program version.\n"));
+  fprintf(stderr, NLS_CATGETS(catfd, rarpSet, rarp_usage1,
+  "Usage: rarp -a                               list entries in cache.\n"));
+  fprintf(stderr, NLS_CATGETS(catfd, rarpSet, rarp_usage2,
+  "       rarp -d hostname                      delete entry from cache.\n"));
+  fprintf(stderr, NLS_CATGETS(catfd, rarpSet, rarp_usage3,
+  "       rarp [-t hwtype] -s hostname hwaddr   add entry to cache.\n"));
+  fprintf(stderr, NLS_CATGETS(catfd, rarpSet, rarp_usage4,
+  "       rarp -V                               display program version.\n"));
+  NLS_CATCLOSE(catfd)
   exit(-1);
 }
 
 #define MODE_DISPLAY   1
 #define MODE_DELETE    2
 #define MODE_SET       3
-#define MODE_ETHERS    4
 
 static struct option longopts[] = { 
   { "version", 0, NULL, 'V' },
@@ -200,9 +163,9 @@ int main(int argc, char **argv)
   struct hostent *hp;
   int fd;
 
-#if I18N
-  bindtextdomain("net-tools", "/usr/share/locale");
-  textdomain("net-tools");
+#if NLS
+  setlocale (LC_MESSAGES, "");
+  catfd = catopen ("nettools", MCLoadBySet);
 #endif
 
 #if HAVE_HWETHER
@@ -211,7 +174,7 @@ int main(int argc, char **argv)
 #endif
 
   do {
-    c = getopt_long(argc, argv, "-ht:adsVvf", longopts, NULL);
+    c = getopt_long(argc, argv, "-ht:adsVv", longopts, NULL);
     switch (c) {
     case EOF:
       break;
@@ -219,7 +182,8 @@ int main(int argc, char **argv)
       usage();
     case 'V':
       fprintf(stderr, version_string);
-      exit(1);
+      NLS_CATCLOSE(catfd)
+	exit(1);
       break;
     case 'v':
       verbose++;
@@ -228,15 +192,12 @@ int main(int argc, char **argv)
     case 's':
     case 'd':
       if (mode) {
-	fprintf(stderr, _("%s: illegal option mix.\n"), argv[0]);
+	fprintf(stderr, "%s: illegal option mix.\n", argv[0]);
 	usage();
       } else {
 	mode = (c == 'a'?MODE_DISPLAY:(c == 'd'?MODE_DELETE:MODE_SET));
       }
       break;
-    case 'f':
-      mode=MODE_ETHERS;
-      break;
     case 't':
       if (optarg) {
 	hardware = get_hwtype(optarg);
@@ -257,9 +218,15 @@ int main(int argc, char **argv)
     }
   } while (c != EOF);
 
+  if (nargs != (mode-1)) {
+    usage();
+  }
+
   if (hardware == NULL) {
-    fprintf(stderr, _("rarp: %s: unknown hardware type.\n"), optarg);
-    exit(1);
+    fprintf(stderr, NLS_CATGETS(catfd, rarpSet, rarp_unkn_hw,
+				"rarp: %s: unknown hardware type.\n"), optarg);
+    NLS_CATCLOSE(catfd)
+      exit(1);
   }
 
   switch (mode) {
@@ -267,38 +234,26 @@ int main(int argc, char **argv)
     usage();
 
   case MODE_DISPLAY:
-  if (nargs != (mode-1)) {
-    usage();
-  }
     result = display_cache();
     break;
 
   case MODE_DELETE:
   case MODE_SET:
-  if (nargs != (mode-1)) {
-    usage();
-  }
     if ((hp = gethostbyname(args[0])) == NULL) {
-	fprintf(stderr, _("rarp: %s: unknown host\n"), args[0]);
+      fprintf(stderr, NLS_CATGETS(catfd, rarpSet, rarp_unkn_host, 
+				  "rarp: %s: unknown host\n"), args[0]);
+      NLS_CATCLOSE(catfd)
 	exit(1);
     }
     if (fd = socket(PF_INET, SOCK_DGRAM, 0), fd < 0) {
-	perror("socket");
+      perror("socket");
+      NLS_CATCLOSE(catfd)
 	exit (1);
     }
-    result = (mode == MODE_DELETE)?rarp_delete(fd, hp):rarp_set(fd, hp, args[1]);
+    result = (mode == MODE_DELETE)?arp_delete(fd, hp):arp_set(fd, hp, args[1]);
     close(fd);
-    break;
-
-  case MODE_ETHERS:
-    if (nargs!=0 && nargs!=1) usage();
-    if (fd = socket(PF_INET, SOCK_DGRAM, 0), fd < 0) {
-	perror("socket");
-	exit (1);
-    }
-    result = rarp_file(fd, nargs ? args[0] : _PATH_ETHERS);
-    close(fd);
-
   }
+
+  NLS_CATCLOSE(catfd)
     exit(result);
 }
